@@ -53,6 +53,14 @@ commands = [
     Command(("采访",), interview, arg_num=1),
     Command(("打拳",), punch, convert=False),
     Command(("群青",), cyan),
+    Command(("捣",), pound),
+    Command(("捶",), thump),
+    Command(("需要", "你可能需要"), need),
+    Command(("捂脸",), cover_face),
+    Command(("敲",), knock),
+    Command(("垃圾", "垃圾桶"), garbage),
+    Command(("为什么@我", "为什么at我"), whyatme),
+    Command(("像样的亲亲",), decent_kiss, convert=False),
 ]
 
 
